"""
Modul utama pypipr yang berisi semua yg ada dalam pypipr.
"""
from .ibuiltins.avg import *
from .ibuiltins.basename import *
from .ibuiltins.chunk_array import *
from .ibuiltins.ComparePerformance import *
from .ibuiltins.create_folder import *
from .ibuiltins.datetime_from_string import *
from .ibuiltins.datetime_now import *
from .ibuiltins.dict_first import *
from .ibuiltins.dirname import *
from .ibuiltins.exit_if_empty import *
from .ibuiltins.filter_empty import *
from .ibuiltins.get_class_method import *
from .ibuiltins.get_filemtime import *
from .ibuiltins.get_filesize import *
from .ibuiltins.is_empty import *
from .ibuiltins.is_iterable import *
from .ibuiltins.is_valid_url import *
from .ibuiltins.LINUX import *
from .ibuiltins.password_generator import *
from .ibuiltins.random_bool import *
from .ibuiltins.RunParallel import *
from .ibuiltins.set_timeout import *
from .ibuiltins.sets_ordered import *
from .ibuiltins.str_cmp import *
from .ibuiltins.to_str import *
from .ibuiltins.WINDOWS import *
from .iconsole.console_run import *
from .iconsole.input_char import *
from .iconsole.log import *
from .iconsole.print_colorize import *
from .iconsole.print_dir import *
from .iconsole.print_log import *
from .iconsole.text_colorize import *
from .idjango.APIMixinView import *
from .iengineering.batch_calculate import *
from .iengineering.batchmaker import *
from .iengineering.calculate import *
from .iengineering.PintUreg import *
from .iengineering.PintUregQuantity import *
from .iflow.github_pull import *
from .iflow.github_push import *
from .iflow.github_user import *
from .iflow.pip_freeze_without_version import *
from .iflow.poetry_publish import *
from .iflow.poetry_update_version import *
from .ifunctions.idumps import *
from .ifunctions.idumps_html import *
from .ifunctions.ienv import *
from .ifunctions.iexec import *
from .ifunctions.ijoin import *
from .ifunctions.iloads import *
from .ifunctions.iloads_html import *
from .ifunctions.iopen import *
from .ifunctions.iprint import *
from .ifunctions.irange import *
from .ifunctions.ireplace import *
from .ifunctions.iscandir import *
from .ifunctions.isplit import *
